CREATE OR REPLACE VIEW fw_sys_stat_schema (version) AS
	SELECT '3.0.0'
	FROM dual;

CREATE TABLE FW_SYS_STAT_FSM_TYPES
   		     (ID 			NUMBER,
   		      NAME 			VARCHAR2(128) NOT NULL,
   		      SYSTEM_ID		NUMBER,
   		      PANEL 		VARCHAR2(256),
   		      ACTIONS_DPE 	VARCHAR2(256),
   		      STATES_DPE  	VARCHAR2(256),
   		      INIT_SCRIPT   VARCHAR2(4000),
   		      CMD_SCRIPT   VARCHAR2(4000),
   		      STATE_SCRIPT   VARCHAR2(4000),
   		      IS_DEVICE 	NUMBER,
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_TYPES_ID_PK PRIMARY KEY (ID));

CREATE TABLE FW_SYS_STAT_FSM_TYPE_OBJ_PARS
   		     (ID 			NUMBER,
   		      PARAM 		VARCHAR2(256) NOT NULL,
   		      TYPE_ID 		NUMBER,
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_TYPE_OBJECT_PARAMS_ID_PK PRIMARY KEY (ID));

CREATE TABLE FW_SYS_STAT_FSM_ACTIONS
   		     (ID 			NUMBER,
   		      NAME 			VARCHAR2(128) NOT NULL,
   		      TYPE_ID		NUMBER,
   		      PARAMS 		VARCHAR2(4000),
   		      VISIBILITY 	NUMBER,
   		      SML	 		VARCHAR2(4000),
   		      UNKNOWN1 		VARCHAR2(4000),
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_ACTIONS_ID_PK PRIMARY KEY (ID));

CREATE TABLE FW_SYS_STAT_FSM_STATES
   		     (ID 			NUMBER,
   		      NAME 			VARCHAR2(128) NOT NULL,
   		      TYPE_ID		NUMBER,
   		      COLOR 		VARCHAR2(64),
   		      WHEN 		VARCHAR2(4000),
   		      UNKNOWN1 		VARCHAR2(4000),
   		      UNKNOWN2 		VARCHAR2(4000),
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_STATES_ID_PK PRIMARY KEY (ID));


CREATE TABLE FW_SYS_STAT_FSM_NODES
   		     (ID 			NUMBER,
   		      NAME 			VARCHAR2(128),
   		      TYPE_ID		NUMBER,
   		      DEVICE		VARCHAR2(256),
   		      IS_CU	 		NUMBER,
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_NODES_ID_PK PRIMARY KEY (ID));

CREATE TABLE FW_SYS_STAT_FSM_NODE_USERDATA
   		     (ID 			NUMBER,
   		      NODE_ID		NUMBER,
   		      DATA			VARCHAR2(4000),
   		      VALID_UNTIL 	DATE,
			  CONSTRAINT FSM_NODE_USERDATA_ID_PK PRIMARY KEY (ID));

CREATE TABLE FW_SYS_STAT_FSM_HIERARCHIES
   		     (NODE_ID 			NUMBER,
   		      PARENT_NODE_ID	NUMBER,
   		      VALID_UNTIL 	DATE);


ALTER TABLE FW_SYS_STAT_FSM_ACTIONS
	ADD CONSTRAINT FSM_ACTIONS_TYPE_ID_FK
	FOREIGN KEY (TYPE_ID)
	REFERENCES FW_SYS_STAT_FSM_TYPES(ID) ON DELETE CASCADE;


ALTER TABLE FW_SYS_STAT_FSM_STATES
	ADD CONSTRAINT FSM_STATES_TYPE_ID_FK
	FOREIGN KEY (TYPE_ID)
	REFERENCES FW_SYS_STAT_FSM_TYPES(ID) ON DELETE CASCADE;


ALTER TABLE FW_SYS_STAT_FSM_TYPE_OBJ_PARS
	ADD CONSTRAINT FSM_TYPE_OBJECT_PARAMS_ID_FK
	FOREIGN KEY (TYPE_ID)
	REFERENCES FW_SYS_STAT_FSM_TYPES(ID) ON DELETE CASCADE;

ALTER TABLE FW_SYS_STAT_FSM_NODES
	ADD CONSTRAINT FSM_NODES_TYPE_ID_FK
	FOREIGN KEY (TYPE_ID)
	REFERENCES FW_SYS_STAT_FSM_TYPES(ID) ON DELETE CASCADE;

ALTER TABLE FW_SYS_STAT_FSM_NODE_USERDATA
	ADD CONSTRAINT FSM_NODES_USERDATA_ID_FK
	FOREIGN KEY (NODE_ID)
	REFERENCES FW_SYS_STAT_FSM_NODES(ID) ON DELETE CASCADE;


ALTER TABLE FW_SYS_STAT_FSM_HIERARCHIES
	ADD CONSTRAINT FSM_HIERARCHIES_NODES_ID_FK
	FOREIGN KEY (NODE_ID)
	REFERENCES FW_SYS_STAT_FSM_NODES(ID) ON DELETE CASCADE;

ALTER TABLE FW_SYS_STAT_FSM_HIERARCHIES
	ADD CONSTRAINT FSM_HIERARCHIES_P_NODES_ID_FK
	FOREIGN KEY (PARENT_NODE_ID)
	REFERENCES FW_SYS_STAT_FSM_NODES(ID) ON DELETE CASCADE;

CREATE SEQUENCE FW_SYS_STAT_FSM_TYPES_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;

CREATE SEQUENCE FW_SYS_STAT_FSM_ACTIONS_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;

CREATE SEQUENCE FW_SYS_STAT_FSM_STATES_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;


CREATE SEQUENCE FW_SYS_STAT_FSM_SCRIPTS_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;

CREATE SEQUENCE FW_SYS_STAT_FSM_T_OBJ_PARS_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;

CREATE SEQUENCE FW_SYS_STAT_FSM_NODES_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;

CREATE SEQUENCE FW_SYS_STAT_FSM_NODE_USER_SQ
    MINVALUE 1
    MAXVALUE 9999999
    START WITH 1
    INCREMENT BY 1
    NOCACHE;
